#!/usr/bin/python
# -*- encoding: utf-8; py-indent-offset: 4 -*-
#
# License: GNU General Public License v2
#
# Author: thl-cmk[at]outlook[dot]com
# URL   : https://thl-cmk.hopto.org
# Date  : 2018-03-17
#
# Check Point Logserver metrics plugins
# checkpoint_fw_ls / checkpoint_fwm_ls
#

##############################################################################
#
# define units for perfdata
#
##############################################################################

##############################################################################
#
# define metrics for perfdata
#
##############################################################################

metric_info['checkpoint_fw_ls_localloggingwriterate'] = {
    'title': _('Local Logging Writing Rate'),
    'unit': '1/s',
    'color': '11/a',
}
metric_info['checkpoint_fw_ls_logginghandlingrate'] = {
    'title': _('Logging Handling Rate'),
    'unit': '1/s',
    'color': '21/a',
}
metric_info['checkpoint_fw_ls_lsconnsendrate'] = {
    'title': _('Sending Rate'),
    'unit': '1/s',
    'color': '31/a',
}

metric_info['checkpoint_fwm_ls_totalreadlogs'] = {
    'title': _('Total read logs'),
    'unit': '1/s',
    'color': '11/a',
}
metric_info['checkpoint_fwm_ls_totalupdatesandlogsindexed'] = {
    'title': _('Total updates and logs indexed'),
    'unit': 'count',
    'color': '21/a',
}
metric_info['checkpoint_fwm_ls_totalreadlogserrors'] = {
    'title': _('Total read log errors'),
    'unit': '1/s',
    'color': '31/a',
}
metric_info['checkpoint_fwm_ls_totalupdatesandlogsindexederrors'] = {
    'title': _('Total updates and logs indexed errors'),
    'unit': 'count',
    'color': '41/a',
}

metric_info['checkpoint_fwm_ls_updatesandlogsindexedrate'] = {
    'title': _('Updates and logs index rate'),
    'unit': '1/s',
    'color': '12/a',
}
metric_info['checkpoint_fwm_ls_updatesandlogsindexedratepeak'] = {
    'title': _('Updates and logs peak index rate'),
    'unit': '1/s',
    'color': '22/a',
}

metric_info['checkpoint_fwm_ls_readlogsrate'] = {
    'title': _('Logs read rate'),
    'unit': '1/s',
    'color': '12/a',
}
metric_info['checkpoint_fwm_ls_readlogsratepeak'] = {
    'title': _('Logs read peak rate'),
    'unit': '1/s',
    'color': '22/a',
}

##############################################################################
#
# map perfdata to metric
#
##############################################################################


check_metrics['check_mk-checkpoint_fw_ls'] = {
    'fwlocalloggingwriterate': {'name': 'checkpoint_fw_ls_localloggingwriterate', },
    'fwlogginghandlingrate': {'name': 'checkpoint_fw_ls_logginghandlingrate', },
    'fwlsconnsendrate': {'name': 'checkpoint_fw_ls_lsconnsendrate', },
}
check_metrics['check_mk-checkpoint_fwm_ls'] = {
    'totalreadlogs': {'name': 'checkpoint_fwm_ls_totalreadlogs', },
    'totalupdatesandlogsindexed': {'name': 'checkpoint_fwm_ls_totalupdatesandlogsindexed', },
    'totalreadlogserrors': {'name': 'checkpoint_fwm_ls_totalreadlogserrors', },
    'totalupdatesandlogsindexederrors': {'name': 'checkpoint_fwm_ls_totalupdatesandlogsindexederrors', },
    'updatesandlogsindexedrate': {'name': 'checkpoint_fwm_ls_updatesandlogsindexedrate', },
    'updatesandlogsindexedratepeak': {'name': 'checkpoint_fwm_ls_updatesandlogsindexedratepeak', },
    'readlogsrate': {'name': 'checkpoint_fwm_ls_readlogsrate', },
    'readlogsratepeak': {'name': 'checkpoint_fwm_ls_readlogsratepeak', }

}

##############################################################################
#
# how to graph perdata
#
##############################################################################

graph_info.append({
    'title': _('Check Point Firewall Logserver: over all'),
    'metrics': [
        ('checkpoint_fw_ls_localloggingwriterate', 'line'),
        ('checkpoint_fw_ls_logginghandlingrate', 'line'),
    ],
})

graph_info.append({
    'title': _('Check Point Firewall Log server'),
    'metrics': [
        ('checkpoint_fw_ls_lsconnsendrate', 'line'),
    ],
})

graph_info.append({
    'title': _('Check Point Management Firewall Log server'),
    'metrics': [
        ('checkpoint_fwm_ls_updatesandlogsindexedratepeak', 'line'),
        ('checkpoint_fwm_ls_updatesandlogsindexedrate', 'line'),
    ],
})

graph_info.append({
    'title': _('Check Point Management Firewall Log server read logs'),
    'metrics': [
        ('checkpoint_fwm_ls_totalreadlogserrors', 'line'),
        ('checkpoint_fwm_ls_totalreadlogs', 'line'),
    ],
})

graph_info.append({
    'title': _('Check Point Management Firewall Log server updates and logs indexed'),
    'metrics': [
        ('checkpoint_fwm_ls_totalupdatesandlogsindexederrors', 'line'),
        ('checkpoint_fwm_ls_totalupdatesandlogsindexed', 'line'),
    ],
})

##############################################################################
#
# define perf-o-meter
#
##############################################################################

perfometer_info.append(('stacked', [
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_fw_ls_localloggingwriterate',
        'half_value': 1000.0,
        'exponent': 2,
    },
    {
        'type': 'logarithmic',
        'metric': 'checkpoint_fw_ls_localloggingwriterate',
        'half_value': 1000.0,
        'exponent': 2,
    },
]))